@@ -26,7 +26,7 @@
 #' pam <- bamm::models2pam(en_models,
 #'                         return_coords=TRUE,
 #'                         sparse=FALSE,
-#'                         parallel=FALSE,ncores=2)
+#'                         parallel=FALSE,ncores=1)
 #' head(pam)
 #' }
 models2pam <- function(mods_stack,return_coords=FALSE,sparse=TRUE,
@@ -40,68 +40,44 @@ models2pam <- function(mods_stack,return_coords=FALSE,sparse=TRUE,
     nsps <- raster::nlayers(mods_stack)
     rvals <- mods_stack[[1]][]
     cellIDs <- which(!is.na(rvals))
+    if(parallel){
+      oplan <- plan(multisession,workers=ncores)
+      on.exit(plan(oplan), add = TRUE)
+    }
 
     if(!sparse){
-      if(!parallel){
-        pam0 <- 1:nsps %>% purrr::map_dfc(function(x){
-          m1 <- mods_stack[[x]]
-          m2 <- m1[]
-          m3 <- m2[cellIDs]
-          df1 <- data.frame(m3)
-          df1 <- stats::setNames(df1,names(m1))
-          return(df1)
-        })
-      } else{
-        oplan <- plan(multisession,workers=ncores)
-        on.exit(plan(oplan), add = TRUE)
-        pam0 <- 1:nsps %>% furrr::future_map_dfc(function(x){
-          m1 <- mods_stack[[x]]
-          m2 <- m1[]*1
-          m3 <- m2[cellIDs]
-          df1 <- data.frame(m3)
-          df1 <- stats::setNames(df1,names(m1))
-          return(df1)
-        },.progress = TRUE,
-        .options = furrr::furrr_options(seed = NULL,packages = "raster"))
-      }
-      #future::plan(future::sequential)
+      pam0 <- seq_len(nsps) |> furrr::future_map_dfc(function(x){
+        m1 <- mods_stack[[x]]
+        m2 <- m1[]*1
+        m3 <- m2[cellIDs]
+        df1 <- data.frame(m3)
+        df1 <- stats::setNames(df1,names(m1))
+        return(df1)
+      },.progress = TRUE,
+      .options = furrr::furrr_options(seed = NULL,
+                                      globals = c("mods_stack","cellIDs"),
+                                      packages = "raster"))
       pam0 <- data.matrix(pam0)
       if(return_coords){
         xys <- sp::coordinates(mods_stack[[1]])[cellIDs,]
         pam0 <- data.frame(xys,pam0)
       }
       return(pam0)
-    }
-    else{
-      if(!parallel){
-        pamL <- 1:nsps %>% purrr::map(function(x){
-          m1 <- mods_stack[[x]]
-          m2 <- m1[]
-          m3 <- m2[cellIDs]
-          unosIDs <- which(m3==1)
-          msparse0 <- Matrix::sparseVector(x = rep(1,length(unosIDs)),
-                                           i = unosIDs,
-                                           length=length(cellIDs))
-          return(msparse0)
-        })
-      } else{
-        oplan <- plan(multisession,workers=ncores)
-        on.exit(plan(oplan), add = TRUE)
-        pamL <- 1:nsps %>% furrr::future_map(function(x){
-          m1 <- mods_stack[[x]]
-          m2 <- m1[]*1.0
-          m3 <- m2[cellIDs]
-          unosIDs <- which(m3==1)
-          msparse0 <- Matrix::sparseVector(x = rep(100,length(unosIDs)),
-                                           i = unosIDs,
-                                           length=length(cellIDs))
+    } else{
+      pamL <- seq_len(nsps) |> furrr::future_map(function(x){
+        m1 <- mods_stack[[x]]
+        m2 <- m1[]*1.0
+        m3 <- m2[cellIDs]
+        unosIDs <- which(m3==1)
+        msparse0 <- Matrix::sparseVector(x = rep(100,length(unosIDs)),
+                                         i = unosIDs,
+                                         length=length(cellIDs))
 
-          #msparse0 <- Matrix::Matrix(msparse0,sparse = T)
-          return(msparse0)
-        },.progress = TRUE,
-        .options = furrr::furrr_options(seed = NULL,packages = "raster"))
-        #future::plan(future::sequential)
-      }
+        return(msparse0)
+      },.progress = TRUE,
+      .options = furrr::furrr_options(seed = NULL,
+                                      globals = c("mods_stack","cellIDs"),
+                                      packages = "raster"))
 
       pamL <- lapply(pamL, as, "sparseMatrix")
       pam0 <- pamL[[1]]
@@ -118,6 +94,6 @@ models2pam <- function(mods_stack,return_coords=FALSE,sparse=TRUE,
       }
       return(pam0)
     }
-
   }
 }
+
